@@ -37,6 +37,8 @@
 #define GCONF_SMS_DELIVERY_REPORT_KEY	"/apps/phonelink/SMSDeliveryReport"
 #define GCONF_NOTIFY_CALL_KEY 			"/apps/phonelink/NotifyMeForIncomingCall"
 #define GCONF_NOTIFY_SMS_KEY 			"/apps/phonelink/NotifyMeForSMSReception"
+#define GCONF_SHOW_DIALPAD_KEY 		"/apps/phonelink/ShowDialPad"
 
+#define DIALPAD_DATA_KEY				"phonelink.dialpad"
 
 #endif //PHONELINK_H
